@@ -1,5 +1,5 @@
 package cyrillic;
-$curillic::VERSION = '1.20';
+$curillic::VERSION = '1.21';
 
 =head1 NAME
 
@@ -138,7 +138,7 @@ sub prepare
     my($src, $dst)=map $$_[2], @CODEPAGE{@_};
     substr($src, length $1, length $2) = '',
     substr($dst, length $1, length $2) = ''  while $dst =~ /^(.+?)( +)/;
-    substr($_, 66, 0) = '\x00-\x7f' for $src, $dst;
+    substr($_, 66, 0) = '\x00-\x7f', s/-/\\-/g for $src, $dst;
     return $src, $dst;
 }
 
@@ -176,11 +176,6 @@ sub upfirst($;$)
     return &$fn( shift );
 }
 
-sub charset($)
-{
-    return $CODEPAGE{shift()}[1];
-}
-
 sub lofirst($;$)
 {
     my $cs = exists $CP_NAME{$_[0]} ? $CP_NAME{shift()} : shift;
@@ -189,6 +184,11 @@ sub lofirst($;$)
     return &$fn( shift );
 }
 
+sub charset($)
+{
+    return $CODEPAGE{shift()}[1];
+}
+
 sub detect(@)
 {
     my (@data, %score) = @_;
